@@ -1,4 +1,3 @@
-
 import logging
 
 logger = logging.getLogger(__name__)
@@ -9,8 +8,12 @@ def get_latest_parse_data_language(all_events):
     try:
         while True:
             event = next(events)
-            if event['event'] == 'user' and 'parse_data' in event and 'language' in event['parse_data']:
-                return event['parse_data']['language']
+            if (
+                event["event"] == "user"
+                and "parse_data" in event
+                and "language" in event["parse_data"]
+            ):
+                return event["parse_data"]["language"]
 
     except StopIteration:
         return None
